import 'package:easy_alert/src/toast.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

/// Supply text for alert, cancel and ok
/// 为Alert提供文字，一般为取消和确认
class AlertConfig {
  final String ok;
  final String cancel;
  final bool useIosStyle;
  final EdgeInsetsGeometry toastPadding;

  const AlertConfig(
      {this.ok: "OK",
      this.cancel: "CANCEL",
      this.useIosStyle: true,
      this.toastPadding: const EdgeInsets.all(30)});
}

class AlertProvider extends StatelessWidget {
  final Widget child;

  final AlertConfig config;

  final TextDirection textDirection;

  final ToastController controller;

  AlertProvider(
      {this.child,
      this.config: const AlertConfig(),
      this.textDirection = TextDirection.ltr})
      : controller = new ToastController();

  static AlertConfig getConfig(BuildContext context) {
    final _AlertScope scope =
        context.dependOnInheritedWidgetOfExactType(aspect: _AlertScope);
    return scope?.config;
  }

  static AlertConfig getToaster(BuildContext context) {
    final _AlertScope scope =
        context.dependOnInheritedWidgetOfExactType(aspect: _AlertScope);
    return scope?.config;
  }

  static ToastManager getManager(BuildContext context) {
    final _AlertScope scope =
        context.dependOnInheritedWidgetOfExactType(aspect: _AlertScope);

    return scope?.manager;
  }

  @override
  Widget build(BuildContext context) {
    return new Material(
        child: new Stack(
      textDirection: TextDirection.ltr,
      children: <Widget>[
        new _AlertScope(
          manager: controller,
          config: config,
          child: child,
        ),
        new ToastControlView(
          config: config,
          textDirection: textDirection,
          controller: controller,
        )
      ],
    ));
  }
}

class _AlertScope extends InheritedWidget {
  const _AlertScope({Key key, this.config, this.manager, Widget child})
      : super(key: key, child: child);

  final AlertConfig config;
  final ToastManager manager;

  @override
  bool updateShouldNotify(_AlertScope old) {
    return config != old.config;
  }
}
